<?php

/**
 * This is the model class for table "crc".
 *
 * The followings are the available columns in table 'crc':
 * @property string $crcid
 * @property string $crcname
 * @property string $crcsymbol
 * @property string $excrate
 * @property string $fisrate
 * @property boolean $isdefault
 * @property string $usrid
 *
 * The followings are the available model relations:
 * @property Begbal[] $begbals
 * @property Acc[] $accs
 * @property Bpa[] $bpas
 * @property Casha[] $cashas
 * @property Bp[] $bps
 * @property Bpcbal[] $bpcbals
 * @property Bpdbal[] $bpdbals
 * @property Bp[] $bps1
 * @property Cmp[] $cmps
 * @property Cstr[] $cstrs
 * @property Defa[] $defas
 * @property Cons[] $cons
 * @property Cbg[] $cbgs
 * @property Cret[] $crets
 * @property Deo[] $deos
 * @property Emptrn[] $emptrns
 * @property Exclog $exclog
 * @property Jnl[] $jnls
 * @property Lgr[] $lgrs
 * @property Prcv[] $prcvs
 * @property Prc[] $prcs
 * @property Payd[] $payds
 * @property Ppaid[] $ppas
 * @property Po[] $pos
 * @property Rcv[] $rcvs
 * @property Purc[] $purcs
 * @property Rcvd[] $rcvds
 * @property Spaid[] $spas
 * @property Sret[] $srets
 * @property Pay[] $pays
 * @property So[] $sos
 * @property Cadj[] $cadjs
 * @property Usr $usr
 * @property Fcn[] $fcns
 * @property Sale[] $sales
 * @property Deli[] $delis
 * @property Pret[] $prets
 * @property Cash[] $cashes
 * @property Item[] $items
 */
class Crc extends CActiveRecord
{
	/**
	 * Returns the static model of the specified AR class.
	 * @param string $className active record class name.
	 * @return Crc the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'crc';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('crcid', 'required'),
			array('crcid, crcsymbol', 'length', 'max'=>5),
			array('crcname', 'length', 'max'=>50),
			array('excrate, fisrate', 'length', 'max'=>19),
			array('usrid', 'length', 'max'=>10),
			array('isdefault', 'safe'),
			// The following rule is used by search().
			// Please remove those attributes that should not be searched.
			array('crcid, crcname, crcsymbol, excrate, fisrate, isdefault, usrid', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'begbals' => array(self::HAS_MANY, 'Begbal', 'crcid'),
			'accs' => array(self::HAS_MANY, 'Acc', 'crcid'),
			'bpas' => array(self::HAS_MANY, 'Bpa', 'crcid'),
			'cashas' => array(self::HAS_MANY, 'Casha', 'crcid'),
			'bps' => array(self::MANY_MANY, 'Bp', 'bpacc(crcid, bpid)'),
			'bpcbals' => array(self::HAS_MANY, 'Bpcbal', 'crcid'),
			'bpdbals' => array(self::HAS_MANY, 'Bpdbal', 'crcid'),
			'bps1' => array(self::HAS_MANY, 'Bp', 'crcid'),
			'cmps' => array(self::HAS_MANY, 'Cmp', 'crcid'),
			'cstrs' => array(self::HAS_MANY, 'Cstr', 'crcid1'),
			'defas' => array(self::HAS_MANY, 'Defa', 'crcid'),
			'cons' => array(self::HAS_MANY, 'Cons', 'crcid'),
			'cbgs' => array(self::HAS_MANY, 'Cbg', 'crcid'),
			'crets' => array(self::HAS_MANY, 'Cret', 'crcid'),
			'deos' => array(self::HAS_MANY, 'Deo', 'crcid'),
			'emptrns' => array(self::HAS_MANY, 'Emptrn', 'crcid'),
			'exclog' => array(self::HAS_ONE, 'Exclog', 'crcid'),
			'jnls' => array(self::HAS_MANY, 'Jnl', 'crcid'),
			'lgrs' => array(self::HAS_MANY, 'Lgr', 'crcid'),
			'prcvs' => array(self::HAS_MANY, 'Prcv', 'crcid'),
			'prcs' => array(self::HAS_MANY, 'Prc', 'crcid'),
			'payds' => array(self::HAS_MANY, 'Payd', 'crcid'),
			'ppas' => array(self::HAS_MANY, 'Ppaid', 'crcid'),
			'pos' => array(self::HAS_MANY, 'Po', 'crcid'),
			'rcvs' => array(self::HAS_MANY, 'Rcv', 'crcid'),
			'purcs' => array(self::HAS_MANY, 'Purc', 'crcid'),
			'rcvds' => array(self::HAS_MANY, 'Rcvd', 'crcid'),
			'spas' => array(self::HAS_MANY, 'Spaid', 'crcid'),
			'srets' => array(self::HAS_MANY, 'Sret', 'crcid'),
			'pays' => array(self::HAS_MANY, 'Pay', 'crcid'),
			'sos' => array(self::HAS_MANY, 'So', 'crcid'),
			'cadjs' => array(self::HAS_MANY, 'Cadj', 'crcid'),
			'usr' => array(self::BELONGS_TO, 'Usr', 'usrid'),
			'fcns' => array(self::HAS_MANY, 'Fcn', 'crcid'),
			'sales' => array(self::HAS_MANY, 'Sale', 'crcid'),
			'delis' => array(self::HAS_MANY, 'Deli', 'crcid'),
			'prets' => array(self::HAS_MANY, 'Pret', 'crcid'),
			'cashes' => array(self::HAS_MANY, 'Cash', 'crcid'),
			'items' => array(self::HAS_MANY, 'Item', 'crcid'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'crcid' => Yii::t('crc', 'crcid'),
			'crcname' => Yii::t('crc', 'crcname'),
			'crcsymbol' => Yii::t('crc', 'crcsymbol'),
			'excrate' => Yii::t('crc', 'excrate'),
			'fisrate' => Yii::t('crc', 'fisrate'),
			'isdefault' => Yii::t('crc', 'isdefault'),
			'usrid' => Yii::t('crc', 'usrid'),
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
	 */
	public function search()
	{
		// Warning: Please modify the following code to remove attributes that
		// should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('crcid',$this->crcid,true);
		$criteria->compare('crcname',$this->crcname,true);
		$criteria->compare('crcsymbol',$this->crcsymbol,true);
		$criteria->compare('excrate',$this->excrate,true);
		$criteria->compare('fisrate',$this->fisrate,true);
		$criteria->compare('isdefault',$this->isdefault);
		$criteria->compare('usrid',$this->usrid,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}
}