<?php

/**
 * This is the model class for table "itgrp".
 *
 * The followings are the available columns in table 'itgrp':
 * @property string $itgrpid
 * @property string $upitgrpid
 * @property string $itgrpname
 * @property integer $itgrplvl
 * @property integer $itgrpidx
 *
 * The followings are the available model relations:
 * @property Bns[] $bns
 * @property Itgrp $upitgrp
 * @property Itgrp[] $itgrps
 * @property Pprc[] $pprcs
 * @property Item[] $items
 */
class Itgrp extends CActiveRecord {

    /**
     * Returns the static model of the specified AR class.
     * @param string $className active record class name.
     * @return Itgrp the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

    /**
     * @return string the associated database table name
     */
    public function tableName() {
        return 'itgrp';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('itgrpid', 'required'),
            array('itgrplvl, itgrpidx', 'numerical', 'integerOnly' => true),
            array('itgrpid, upitgrpid', 'length', 'max' => 10),
            array('itgrpname', 'length', 'max' => 50),
            // The following rule is used by search().
            // Please remove those attributes that should not be searched.
            array('itgrpid, upitgrpid, itgrpname, itgrplvl, itgrpidx', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'bns' => array(self::HAS_MANY, 'Bns', 'itgrpid'),
            'upitgrp' => array(self::BELONGS_TO, 'Itgrp', 'upitgrpid'),
            'itgrps' => array(self::HAS_MANY, 'Itgrp', 'upitgrpid'),
            'pprcs' => array(self::HAS_MANY, 'Pprc', 'itgrpid'),
            'items' => array(self::HAS_MANY, 'Item', 'itgrpid'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'itgrpid' => Yii::t('itgrp', 'itgrpid'),
            'upitgrpid' => Yii::t('itgrp', 'upitgrpid'),
            'itgrpname' => Yii::t('itgrp', 'itgrpname'),
            'itgrplvl' => Yii::t('itgrp', 'itgrplvl'),
            'itgrpidx' => Yii::t('itgrp', 'itgrpidx'),
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
     */
    public function search() {
        // Warning: Please modify the following code to remove attributes that
        // should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('itgrpid', $this->itgrpid, true);
        $criteria->compare('upitgrpid', $this->upitgrpid, true);
        $criteria->compare('itgrpname', $this->itgrpname, true);
        $criteria->compare('itgrplvl', $this->itgrplvl);
        $criteria->compare('itgrpidx', $this->itgrpidx);

        return new CActiveDataProvider($this, array(
                    'criteria' => $criteria,
                ));
    }
    
    public function getOptions() {
        $data = self::model()->findAll(array('order' => 'itgrpname'));

        $dataArray = CHtml::listData($data, 'id', 'itgrpname');

        $empty[''] = 'Pilih Item Group';

        return $empty + $dataArray;
    }

}