<?php

/**
 * This is the model class for table "kitchen".
 *
 * The followings are the available columns in table 'kitchen':
 * @property string $kitchenno
 * @property string $kitchenname
 * @property string $printername
 *
 * The followings are the available model relations:
 * @property Item[] $items
 * @property Hostwo[] $hostwos
 */
class Kitchen extends CActiveRecord
{
	/**
	 * Returns the static model of the specified AR class.
	 * @param string $className active record class name.
	 * @return Kitchen the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'kitchen';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('kitchenno', 'required'),
			array('kitchenno', 'length', 'max'=>15),
			array('kitchenname', 'length', 'max'=>50),
			array('printername', 'length', 'max'=>100),
			// The following rule is used by search().
			// Please remove those attributes that should not be searched.
			array('kitchenno, kitchenname, printername', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'items' => array(self::MANY_MANY, 'Item', 'itemkitchen(kitchenno, itemid)'),
			'hostwos' => array(self::HAS_MANY, 'Hostwo', 'kitchenno'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'kitchenno' => Yii::t('kitchen', 'kitchenno'),
			'kitchenname' => Yii::t('kitchen', 'kitchenname'),
			'printername' => Yii::t('kitchen', 'printername'),
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
	 */
	public function search()
	{
		// Warning: Please modify the following code to remove attributes that
		// should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('kitchenno',$this->kitchenno,true);
		$criteria->compare('kitchenname',$this->kitchenname,true);
		$criteria->compare('printername',$this->printername,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}
}