<?php

/**
 * This is the model class for table "reg".
 *
 * The followings are the available columns in table 'reg':
 * @property string $regid
 * @property string $modulid
 * @property string $regdesc
 * @property string $regval
 * @property boolean $isvisible
 *
 * The followings are the available model relations:
 * @property Modul $modul
 */
class Reg extends CActiveRecord {

    /**
     * Returns the static model of the specified AR class.
     * @param string $className active record class name.
     * @return Reg the static model class
     */
    public static function model($className=__CLASS__) {
        return parent::model($className);
    }

    /**
     * @return string the associated database table name
     */
    public function tableName() {
        return 'reg';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('regid', 'required'),
            array('regid', 'length', 'max' => 15),
            array('modulid', 'length', 'max' => 20),
            array('regdesc', 'length', 'max' => 60),
            array('regval', 'length', 'max' => 30),
            array('isvisible', 'safe'),
            // The following rule is used by search().
            // Please remove those attributes that should not be searched.
            array('regid, modulid, regdesc, regval, isvisible', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'modul' => array(self::BELONGS_TO, 'Modul', 'modulid'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'regid' => Yii::t('reg', 'regid'),
            'modulid' => Yii::t('reg', 'modulid'),
            'regdesc' => Yii::t('reg', 'regdesc'),
            'regval' => Yii::t('reg', 'regval'),
            'isvisible' => Yii::t('reg', 'isvisible'),
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
     */
    public function search() {
        // Warning: Please modify the following code to remove attributes that
        // should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('regid', $this->regid, true);
        $criteria->compare('modulid', $this->modulid, true);
        $criteria->compare('regdesc', $this->regdesc, true);
        $criteria->compare('regval', $this->regval, true);
        $criteria->compare('isvisible', $this->isvisible);

        return new CActiveDataProvider($this, array(
                    'criteria' => $criteria,
                ));
    }

    public function getRegVal($regid) {
        $model = self::model()->findByPk($regid);
        if ($model != null) {
            return $model->regval;
        } else {
            return null;
        }
    }

}