<?php

/**
 * This is the model class for table "saled".
 *
 * The followings are the available columns in table 'saled':
 * @property string $saleno
 * @property integer $saledno
 * @property string $sono
 * @property integer $sodno
 * @property string $taxid
 * @property string $deptid
 * @property string $deono
 * @property integer $deodno
 * @property string $srepid
 * @property string $delino
 * @property integer $delidno
 * @property string $prjid
 * @property string $consno
 * @property integer $consdno
 * @property string $itemid
 * @property string $whid
 * @property string $pid
 * @property string $itemdesc
 * @property string $qty
 * @property string $unit
 * @property string $conv
 * @property string $qtyx
 * @property string $cost
 * @property string $listprice
 * @property string $baseprice
 * @property string $discexp
 * @property string $discamt
 * @property string $disc2amt
 * @property string $taxamt
 * @property boolean $isbonus
 * @property boolean $ischprice
 * @property string $salednote
 * @property string $expdate
 * @property string $subtotal
 * @property string $taxableamt
 * @property string $totaltaxamt
 * @property string $totaldiscamt
 * @property string $totaldisc2amt
 * @property string $basesubtotal
 * @property string $basetotaltaxamt
 * @property string $basftotaltaxamt
 *
 * The followings are the available model relations:
 * @property Consd $consno0
 * @property Consd $consdno0
 * @property Delid $delino0
 * @property Delid $delidno0
 * @property Deod $deono0
 * @property Deod $deodno0
 * @property Dept $dept
 * @property Item $item
 * @property Prj $prj
 * @property Sale $saleno0
 * @property Sod $sono0
 * @property Sod $sodno0
 * @property Srep $srep
 * @property Tax $tax
 * @property Wh $wh
 * @property Sretd[] $sretds
 * @property Sretd[] $sretds1
 */
class Saled extends CActiveRecord
{
	/**
	 * Returns the static model of the specified AR class.
	 * @param string $className active record class name.
	 * @return Saled the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'saled';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('saleno, saledno', 'required'),
			array('saledno, sodno, deodno, delidno, consdno', 'numerical', 'integerOnly'=>true),
			array('saleno, sono, deono, delino, consno, qty, conv, qtyx, discexp', 'length', 'max'=>15),
			array('taxid, deptid, prjid, unit', 'length', 'max'=>5),
			array('srepid', 'length', 'max'=>10),
			array('itemid', 'length', 'max'=>20),
			array('whid', 'length', 'max'=>3),
			array('pid', 'length', 'max'=>25),
			array('itemdesc, salednote', 'length', 'max'=>50),
			array('cost, listprice, baseprice, discamt, disc2amt, taxamt, subtotal, taxableamt, totaltaxamt, totaldiscamt, totaldisc2amt, basesubtotal, basetotaltaxamt, basftotaltaxamt', 'length', 'max'=>19),
			array('isbonus, ischprice, expdate', 'safe'),
			// The following rule is used by search().
			// Please remove those attributes that should not be searched.
			array('saleno, saledno, sono, sodno, taxid, deptid, deono, deodno, srepid, delino, delidno, prjid, consno, consdno, itemid, whid, pid, itemdesc, qty, unit, conv, qtyx, cost, listprice, baseprice, discexp, discamt, disc2amt, taxamt, isbonus, ischprice, salednote, expdate, subtotal, taxableamt, totaltaxamt, totaldiscamt, totaldisc2amt, basesubtotal, basetotaltaxamt, basftotaltaxamt', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'consno0' => array(self::BELONGS_TO, 'Consd', 'consno'),
			'consdno0' => array(self::BELONGS_TO, 'Consd', 'consdno'),
			'delino0' => array(self::BELONGS_TO, 'Delid', 'delino'),
			'delidno0' => array(self::BELONGS_TO, 'Delid', 'delidno'),
			'deono0' => array(self::BELONGS_TO, 'Deod', 'deono'),
			'deodno0' => array(self::BELONGS_TO, 'Deod', 'deodno'),
			'dept' => array(self::BELONGS_TO, 'Dept', 'deptid'),
			'item' => array(self::BELONGS_TO, 'Item', 'itemid'),
			'prj' => array(self::BELONGS_TO, 'Prj', 'prjid'),
			'saleno0' => array(self::BELONGS_TO, 'Sale', 'saleno'),
			'sono0' => array(self::BELONGS_TO, 'Sod', 'sono'),
			'sodno0' => array(self::BELONGS_TO, 'Sod', 'sodno'),
			'srep' => array(self::BELONGS_TO, 'Srep', 'srepid'),
			'tax' => array(self::BELONGS_TO, 'Tax', 'taxid'),
			'wh' => array(self::BELONGS_TO, 'Wh', 'whid'),
			'sretds' => array(self::HAS_MANY, 'Sretd', 'saleno'),
			'sretds1' => array(self::HAS_MANY, 'Sretd', 'saledno'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'saleno' => Yii::t('saled', 'saleno'),
			'saledno' => Yii::t('saled', 'saledno'),
			'sono' => Yii::t('saled', 'sono'),
			'sodno' => Yii::t('saled', 'sodno'),
			'taxid' => Yii::t('saled', 'taxid'),
			'deptid' => Yii::t('saled', 'deptid'),
			'deono' => Yii::t('saled', 'deono'),
			'deodno' => Yii::t('saled', 'deodno'),
			'srepid' => Yii::t('saled', 'srepid'),
			'delino' => Yii::t('saled', 'delino'),
			'delidno' => Yii::t('saled', 'delidno'),
			'prjid' => Yii::t('saled', 'prjid'),
			'consno' => Yii::t('saled', 'consno'),
			'consdno' => Yii::t('saled', 'consdno'),
			'itemid' => Yii::t('saled', 'itemid'),
			'whid' => Yii::t('saled', 'whid'),
			'pid' => Yii::t('saled', 'pid'),
			'itemdesc' => Yii::t('saled', 'itemdesc'),
			'qty' => Yii::t('saled', 'qty'),
			'unit' => Yii::t('saled', 'unit'),
			'conv' => Yii::t('saled', 'conv'),
			'qtyx' => Yii::t('saled', 'qtyx'),
			'cost' => Yii::t('saled', 'cost'),
			'listprice' => Yii::t('saled', 'listprice'),
			'baseprice' => Yii::t('saled', 'baseprice'),
			'discexp' => Yii::t('saled', 'discexp'),
			'discamt' => Yii::t('saled', 'discamt'),
			'disc2amt' => Yii::t('saled', 'disc2amt'),
			'taxamt' => Yii::t('saled', 'taxamt'),
			'isbonus' => Yii::t('saled', 'isbonus'),
			'ischprice' => Yii::t('saled', 'ischprice'),
			'salednote' => Yii::t('saled', 'salednote'),
			'expdate' => Yii::t('saled', 'expdate'),
			'subtotal' => Yii::t('saled', 'subtotal'),
			'taxableamt' => Yii::t('saled', 'taxableamt'),
			'totaltaxamt' => Yii::t('saled', 'totaltaxamt'),
			'totaldiscamt' => Yii::t('saled', 'totaldiscamt'),
			'totaldisc2amt' => Yii::t('saled', 'totaldisc2amt'),
			'basesubtotal' => Yii::t('saled', 'basesubtotal'),
			'basetotaltaxamt' => Yii::t('saled', 'basetotaltaxamt'),
			'basftotaltaxamt' => Yii::t('saled', 'basftotaltaxamt'),
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
	 */
	public function search()
	{
		// Warning: Please modify the following code to remove attributes that
		// should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('saleno',$this->saleno,true);
		$criteria->compare('saledno',$this->saledno);
		$criteria->compare('sono',$this->sono,true);
		$criteria->compare('sodno',$this->sodno);
		$criteria->compare('taxid',$this->taxid,true);
		$criteria->compare('deptid',$this->deptid,true);
		$criteria->compare('deono',$this->deono,true);
		$criteria->compare('deodno',$this->deodno);
		$criteria->compare('srepid',$this->srepid,true);
		$criteria->compare('delino',$this->delino,true);
		$criteria->compare('delidno',$this->delidno);
		$criteria->compare('prjid',$this->prjid,true);
		$criteria->compare('consno',$this->consno,true);
		$criteria->compare('consdno',$this->consdno);
		$criteria->compare('itemid',$this->itemid,true);
		$criteria->compare('whid',$this->whid,true);
		$criteria->compare('pid',$this->pid,true);
		$criteria->compare('itemdesc',$this->itemdesc,true);
		$criteria->compare('qty',$this->qty,true);
		$criteria->compare('unit',$this->unit,true);
		$criteria->compare('conv',$this->conv,true);
		$criteria->compare('qtyx',$this->qtyx,true);
		$criteria->compare('cost',$this->cost,true);
		$criteria->compare('listprice',$this->listprice,true);
		$criteria->compare('baseprice',$this->baseprice,true);
		$criteria->compare('discexp',$this->discexp,true);
		$criteria->compare('discamt',$this->discamt,true);
		$criteria->compare('disc2amt',$this->disc2amt,true);
		$criteria->compare('taxamt',$this->taxamt,true);
		$criteria->compare('isbonus',$this->isbonus);
		$criteria->compare('ischprice',$this->ischprice);
		$criteria->compare('salednote',$this->salednote,true);
		$criteria->compare('expdate',$this->expdate,true);
		$criteria->compare('subtotal',$this->subtotal,true);
		$criteria->compare('taxableamt',$this->taxableamt,true);
		$criteria->compare('totaltaxamt',$this->totaltaxamt,true);
		$criteria->compare('totaldiscamt',$this->totaldiscamt,true);
		$criteria->compare('totaldisc2amt',$this->totaldisc2amt,true);
		$criteria->compare('basesubtotal',$this->basesubtotal,true);
		$criteria->compare('basetotaltaxamt',$this->basetotaltaxamt,true);
		$criteria->compare('basftotaltaxamt',$this->basftotaltaxamt,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}
}