<?php

/**
 * This is the model class for table "sc".
 *
 * The followings are the available columns in table 'sc':
 * @property string $scid
 * @property string $accsc
 * @property string $scname
 * @property string $scexp
 *
 * The followings are the available model relations:
 * @property Sod[] $sods
 * @property Item[] $items
 * @property Saled[] $saleds
 * @property Acc $accsc0
 */
class Sc extends CActiveRecord {

    /**
     * Returns the static model of the specified AR class.
     * @param string $className active record class name.
     * @return Sc the static model class
     */
    public static function model($className=__CLASS__) {
        return parent::model($className);
    }

    /**
     * @return string the associated database table name
     */
    public function tableName() {
        return 'sc';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('scid', 'required'),
            array('scid', 'length', 'max' => 5),
            array('accsc', 'length', 'max' => 10),
            array('scname', 'length', 'max' => 50),
            array('scexp', 'length', 'max' => 15),
            // The following rule is used by search().
            // Please remove those attributes that should not be searched.
            array('scid, accsc, scname, scexp', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'sods' => array(self::HAS_MANY, 'Sod', 'scid'),
            'items' => array(self::HAS_MANY, 'Item', 'scid'),
            'saleds' => array(self::HAS_MANY, 'Saled', 'scid'),
            'accsc0' => array(self::BELONGS_TO, 'Acc', 'accsc'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'scid' => Yii::t('sc', 'scid'),
            'accsc' => Yii::t('sc', 'accsc'),
            'scname' => Yii::t('sc', 'scname'),
            'scexp' => Yii::t('sc', 'scexp'),
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
     */
    public function search() {
        // Warning: Please modify the following code to remove attributes that
        // should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('scid', $this->scid, true);
        $criteria->compare('accsc', $this->accsc, true);
        $criteria->compare('scname', $this->scname, true);
        $criteria->compare('scexp', $this->scexp, true);

        return new CActiveDataProvider($this, array(
                    'criteria' => $criteria,
                ));
    }

    public function getSCExp($scid) {
        $model = self::model()->findByPk($scid);
        if ($model != null) {
            return $model->scexp;
        }else
            return null;
    }

}